@@ -63,10 +63,8 @@ except ImportError:
 if bytes is str:
     # Python 2
     unicode_type = unicode
-    binary_type = str
 else:
     unicode_type = str
-    binary_type = bytes
     
 from lazr.restfulclient.errors import HTTPError
 from lazr.restfulclient.authorize.oauth import (
@@ -191,7 +189,7 @@ class Credentials(OAuthAuthorizer):
         if token_format == self.DICT_TOKEN_FORMAT:
             headers['Accept'] = 'application/json'
         response, content = _http_post(url, headers, params)
-        if isinstance(content, binary_type):
+        if isinstance(content, bytes):
             content = content.decode('utf-8')
         if token_format == self.DICT_TOKEN_FORMAT:
             params = json.loads(content)
@@ -248,6 +246,8 @@ class AccessToken(_AccessToken):
     @classmethod
     def from_string(cls, query_string):
         """Create and return a new `AccessToken` from the given string."""
+        if not isinstance(query_string, unicode_type):
+            query_string = query_string.decode('utf-8')
         params = cgi.parse_qs(query_string, keep_blank_values=False)
         key = params['oauth_token']
         assert len(key) == 1, (
@@ -639,7 +639,7 @@ class AuthorizeRequestTokenWithBrowser(RequestTokenAuthorizationEngine):
             browser = getattr(browser_obj, "basename", None)
             console_browser = browser in self.TERMINAL_BROWSERS
         except webbrowser.Error:
-            browser = None
+            browser_obj = None
             console_browser = False
 
         if console_browser:
